@@ -39,7 +39,7 @@ mod server;
 mod tests;
 
 pub use future::{ServerHandle as WsServerHandle, ShutdownWaiter as WsShutdownWaiter};
-pub use jsonrpsee_core::server::rpc_module::{RpcModule, SubscriptionSink};
+pub use jsonrpsee_core::server::rpc_module::{PendingSubscription, RpcModule, SubscriptionSink};
 pub use jsonrpsee_core::{id_providers::*, traits::IdProvider};
 pub use jsonrpsee_types as types;
 pub use server::{Builder as WsServerBuilder, Server as WsServer};
